.. mdinclude:: ../README.md

.. simple_email documentation master file, created by
   sphinx-quickstart on Fri Oct 19 11:15:29 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:

   changelog
   installation
   api
   contributing
